#include<cstdio>
#include<cstdlib>
#include<cassert>
#include<cstring>
#include<cmath>
#define MAX(a, b) ((a) > (b) ? (a) : (b))
#define MIN(a, b) ((a) < (b) ? (a) : (b))

enum {
  DIGITS_IN_BASE = 4,
  BASE = 10000,

  MAXN = 500 * 1000 + 1,
  MAX_FFT_LOG_SIZE = 20,
  MAX_FFT_SIZE = 1 << MAX_FFT_LOG_SIZE,

  BASECASE_MULTIPLY_THRESHOLD = 200,

  BASECASE_DIVIDE_THRESHOLD = 30,
};

//---------------------- MY COMPLEX ----------------------------------

struct MyComplex {
  double re;
  double im;

  MyComplex() {
    re = im = 0.0;
  }

  MyComplex(double re_, double im_) {
    re = re_;
    im = im_;
  }

  inline const MyComplex operator*(const MyComplex &a) const {
    return MyComplex(re * a.re - im * a.im, re * a.im + im * a.re);
  }

  inline const MyComplex operator-(const MyComplex &a) const {
    return MyComplex(re - a.re, im - a.im);
  }

  inline const MyComplex& operator+=(const MyComplex &a) {
    re += a.re;
    im += a.im;
    return *this;
  }

  inline const MyComplex& operator*=(double a) {
    re *= a;
    im *= a;
    return *this;
  }
};

//---------------------- COMMON FUNCTIONS ----------------------------

const int ONE = 1;

char string_number[MAXN + 1];

// a should have enough capacity
void read_number(int *a, int *size) {
  scanf("%s", string_number);
  int real_size = 0;
  for (int i = strlen(string_number); i > 0; i -= DIGITS_IN_BASE) {
    string_number[i] = 0;
    a[real_size++] = atoi(i >= DIGITS_IN_BASE ? string_number + i - DIGITS_IN_BASE : string_number);
  }
  *size = real_size;
}

void write_number(const int *a, int size) {
  if (size == 0) {
    printf("0\n");
    return;
  }
  printf("%d", a[size - 1]);
  for (int i = size - 2; i >= 0; --i) {
    printf("%04d", a[i]);
  }
  printf("\n");
}

int upper_pow2(int n) {
  int ans = 1;
  while (ans < n) {
    ans <<= 1;
  }
  return ans;
}

int log2(int n) {
  int ans = 0;
  while (n > 1) {
    n >>= 1;
    ++ans;
  }
  return ans;
}

int num_len(int n) { // n > 0
  int ans = 0;
  while (n > 0) {
    n /= 10;
    ++ans;
  }
  return ans;
}

void set_size(const int *result, int size, int *result_size) {
  int real_size = size;
  while (real_size > 0 && !result[real_size - 1]) {
    --real_size;
  }
  *result_size = real_size;
}

int compare(const int *a, int a_size, const int *b, int b_size) {
  while (a_size > 0 && a_size > b_size) {
    if (a[--a_size]) {
      return 1;
    }
  }

  while (b_size > 0 && b_size > a_size) {
    if (b[--b_size]) {
      return -1;
    }
  }

  // now sizes are equal    
  int a_digit, b_digit;
  for (int i = a_size - 1; i >= 0; --i) {
    a_digit = a[i];
    b_digit = b[i];
    if (a_digit < b_digit) {
      return -1;
    }
    if (a_digit > b_digit) {
      return 1;
    }
  }
  return 0;
}

// a must be >= b
void inplace_subtract(int *a, int a_size, const int *b, int b_size, int *result_size) {
  int carry = 0, diff;
  for (int i = 0; i < b_size || carry; ++i) {
    diff = a[i] - carry - (i < b_size ? b[i] : 0);
    carry = diff < 0;
    if (carry) {
      diff += BASE;
    }
    a[i] = diff;
  }
  set_size(a, a_size, result_size);
}

// a must be long enough to contain the result
void inplace_add(int *a, int a_size, const int *b, int b_size, int *result_size) {
  int i, carry = 0;
  for (i = 0; i < MAX(a_size, b_size) || carry; ++i) {
    a[i] = (i < a_size ? a[i] : 0) + carry + (i < b_size ? b[i] : 0);
    carry = a[i] >= BASE;
    if (carry) {
      a[i] -= BASE;
    }
  }
  *result_size = i;
}

void multiply_by_short(const int *a, int a_size, int b, int *result, int *result_size) {
  if (a_size == 0) {
    *result_size = 0;
    return;
  }
  int i, sum, carry = 0;
  for (i = 0; i < a_size || carry; ++i) {
    sum = (i < a_size ? a[i] : 0) * b + carry;
    carry = sum / BASE;
    result[i] = sum - carry * BASE;
  }
  *result_size = i;
}

// returns residual
int inplace_divide_by_short(int *a, int a_size, int b, int *result_size) {
  if (a_size == 0) {
    *result_size = 0;
    return 0;
  }
  int sum, carry = 0;
  for (int i = a_size - 1; i >= 0; --i) {
    sum = a[i] + carry * BASE;
    a[i] = sum / b;
    carry = sum - a[i] * b;
  }
  set_size(a, a_size, result_size);
  return carry;
}

//--------------------- MULTIPLICATION -------------------------------

const double PI = 3.14159265358979323846;

// FFT MULTIPLICATION
int *rev[MAX_FFT_LOG_SIZE];
MyComplex *wlen_pw[MAX_FFT_LOG_SIZE - 1], *wlen_pw_inv[MAX_FFT_LOG_SIZE - 1];

void prepare_fft() {
  // rev
  rev[0] = (int *)malloc(1 * sizeof(int));
  rev[0][0] = 0;
  for (int log_size = 1; log_size < MAX_FFT_LOG_SIZE; ++log_size) {
    int size = 1 << log_size, half_size = 1 << (log_size - 1);
    rev[log_size] = (int *)malloc(size * sizeof(int));
    for (int i = 0; i < half_size; ++i) {
      rev[log_size][i] = 2 * rev[log_size - 1][i];
      rev[log_size][i + half_size] = rev[log_size][i] + 1;
    }
  }

  // wlen_pw
  wlen_pw[MAX_FFT_LOG_SIZE - 2] = (MyComplex *)malloc((MAX_FFT_SIZE >> 2) * sizeof(MyComplex));
  wlen_pw_inv[MAX_FFT_LOG_SIZE - 2] = (MyComplex *)malloc((MAX_FFT_SIZE >> 2) * sizeof(MyComplex));
  wlen_pw[MAX_FFT_LOG_SIZE - 2][0] = wlen_pw_inv[MAX_FFT_LOG_SIZE - 2][0] = MyComplex(1, 0);
  
  int half_size = 1 << (MAX_FFT_LOG_SIZE - 2);
  double ang = 2 * PI / (half_size << 1);
  MyComplex wlen(cos(ang), sin(ang));
  MyComplex *p = wlen_pw[MAX_FFT_LOG_SIZE - 2], *p_inv = wlen_pw_inv[MAX_FFT_LOG_SIZE - 2];
  *p++ = *p_inv++ = MyComplex(1, 0);
  for (int i = 1; i < half_size; ++i, ++p, ++p_inv) {
    *p = *(p - 1) * wlen;
    *p_inv = MyComplex(p->re, -(p->im));
  }
  
  for (int i = MAX_FFT_LOG_SIZE - 3; i >= 0; --i) {
    half_size >>= 1;
    wlen_pw[i] = (MyComplex *)malloc(half_size * sizeof(MyComplex));
    wlen_pw_inv[i] = (MyComplex *)malloc(half_size * sizeof(MyComplex));
    for (int j = 0; j < half_size; ++j) {
      wlen_pw[i][j] = wlen_pw[i + 1][j * 2];
      wlen_pw_inv[i][j] = wlen_pw_inv[i + 1][j * 2];
    }
  }
}

void free_fft() {
  for (int i = 0; i < MAX_FFT_LOG_SIZE; ++i) {
    free(rev[i]);
  }
  for (int i = 0; i < MAX_FFT_LOG_SIZE - 2; ++i) {
    free(wlen_pw[i]);
    free(wlen_pw_inv[i]);
  }
}

void fft(MyComplex arr[], int size, bool invert) {
  for (int len = 8, log = 2; len <= size; len <<= 1, ++log) {
    int len_half = len >> 1;
    for (int i = 0; i < size; i += len) {
      MyComplex temp,
        *pu = arr + i,
        *pv = arr + i + len_half,
        *pu_end = arr + i + len_half,
        *pw = invert ? wlen_pw_inv[log] : wlen_pw[log];
      for (; pu != pu_end; ++pu, ++pv, ++pw) {
        temp = *pv * *pw;
        *pv = *pu - temp;
        *pu += temp;
      }
    }
  }
  if (invert) {
    double inv_size = 1.0 / size;
    for (int i = 0; i < size; ++i) {
      arr[i] *= inv_size;
    }
  }
}

void get_fft_inv(MyComplex *a, int fft_size) {
  if (fft_size == 2) {
    MyComplex tmp = a[1];
    a[1] = a[0] - a[1];
    a[0] += tmp;
    a[0] *= 0.5;
    a[1] *= 0.5;
    return;
  }

  int log_size = log2(fft_size), p;
  int *r = rev[log_size];
  MyComplex tmp;
  for (int i = 0; i < fft_size; ++i) {
    p = r[i];
    if (i < p) {
      tmp = a[i];
      a[i] = a[p];
      a[p] = tmp;
    }
  }
  for (int i = 0; i < fft_size; i += 2) {
    tmp = a[i + 1];
    a[i + 1] = a[i] - tmp;
    a[i] += tmp;
  }
  for (int i = 0; i < fft_size; i += 4) {
    tmp = a[i + 2];
    a[i + 2] = a[i] - tmp;
    a[i] += tmp;

    tmp = a[i + 3];
    a[i + 3] = MyComplex(a[i + 1].re - tmp.im, a[i + 1].im + tmp.re);
    a[i + 1] = MyComplex(a[i + 1].re + tmp.im, a[i + 1].im - tmp.re);
  }
  fft(a, fft_size, true);
}

int fft_int_multiplier[MAX_FFT_SIZE];
int fft_int_multiplier_size;

// doing first 2 iterations of fft int ints
// result must be at least of fft_size
void get_fft(const int *a, int a_size, MyComplex *result, int fft_size) {  
  for (int i = 0, j = 0; i < a_size; ++i, j+=2) {
    fft_int_multiplier[j] = a[i] % 100;
    fft_int_multiplier[j + 1] = a[i] / 100;
  }
  memset(fft_int_multiplier + a_size * 2, 0, (fft_size - a_size * 2) * sizeof(int));

  if (fft_size == 2) {
    result[0] = MyComplex((fft_int_multiplier[0] + fft_int_multiplier[1]), 0);
    result[1] = MyComplex((fft_int_multiplier[0] - fft_int_multiplier[1]), 0);
    return;
  }

  int log_size = log2(fft_size);
  int *r = rev[log_size];
  int p, tmp;
  for (int i = 0; i < fft_size; ++i) {
    p = r[i];
    if (i < p) {
      tmp = fft_int_multiplier[i];
      fft_int_multiplier[i] = fft_int_multiplier[p];
      fft_int_multiplier[p] = tmp;
    }
  }
  for (int i = 0; i < fft_size; i += 2) {
    tmp = fft_int_multiplier[i + 1];
    fft_int_multiplier[i + 1] = fft_int_multiplier[i] - tmp;
    fft_int_multiplier[i] += tmp;
  }
  for (int i = 0; i < fft_size; i += 4) {
    result[i] = MyComplex(fft_int_multiplier[i] + fft_int_multiplier[i + 2], 0);
    result[i + 2] = MyComplex(fft_int_multiplier[i] - fft_int_multiplier[i + 2], 0);

    result[i + 1] = MyComplex(fft_int_multiplier[i + 1], fft_int_multiplier[i + 3]);
    result[i + 3] = MyComplex(fft_int_multiplier[i + 1], -fft_int_multiplier[i + 3]);
  }
  fft(result, fft_size, false);
}

MyComplex fft_multiplier1[MAX_FFT_SIZE], fft_multiplier2[MAX_FFT_SIZE];
int tmp[MAX_FFT_SIZE];

// result must have capacity for at least a_size + b_size elements, function fills them
void fft_multiply(const int *a, int a_size, const int *b, int b_size, int *result, int *result_size) {
  if (a_size == 0 || b_size == 0) {
    *result_size = 0;
    return;
  }

  int a_digits = (a_size - 1) * DIGITS_IN_BASE + num_len(a[a_size - 1]);
  int b_digits = (b_size - 1) * DIGITS_IN_BASE + num_len(b[b_size - 1]);
  int size = upper_pow2(MAX((a_digits + 1) / 2, (b_digits + 1) / 2)) << 1;
  get_fft(a, a_size, fft_multiplier1, size);
  get_fft(b, b_size, fft_multiplier2, size);
  for (int i = 0; i < size; ++i) {
    fft_multiplier1[i] = fft_multiplier1[i] * fft_multiplier2[i];
  }
  get_fft_inv(fft_multiplier1, size);

  int sum, carry = 0;
  for (int i = 0; i < size; ++i) {
    sum = int(fft_multiplier1[i].re + 0.5) + carry;
    carry = sum / 100;
    tmp[i] = sum - carry * 100;
  }
  for (int i = 0, j = 0; j < size; ++i, j += 2) {
    result[i] = tmp[j] + tmp[j + 1] * 100;
  }  
  set_size(result, size / 2, result_size);  
}

// BASECASE MULTIPLICATION
long long basecase_intermediate_result[2 * MAXN];

// result must have capacity for at least a_size + b_size elements, function fills them
void basecase_multiply(const int *a, int a_size, const int *b, int b_size, int *result, int *result_size) {
  if (a_size == 0 || b_size == 0) {
    *result_size = 0;
    return;
  }

  memset(basecase_intermediate_result, 0, (a_size + b_size) * sizeof(long long));
  for (int i = 0; i < a_size; ++i) {
    for (int j = 0; j < b_size; ++j) {
      basecase_intermediate_result[i + j] += a[i] * b[j];
    }
  }
  long long sum, carry = 0;
  for (int i = 0; i < a_size + b_size; ++i) {
    sum = basecase_intermediate_result[i] + carry;
    carry = sum / BASE;
    result[i] = sum - carry * BASE;
  }

  set_size(result, a_size + b_size, result_size);
}

void multiply(const int *a, int a_size, const int *b, int b_size, int *result, int *result_size) {
  if (MAX(a_size, b_size) <= BASECASE_MULTIPLY_THRESHOLD) {
    basecase_multiply(a, a_size, b, b_size, result, result_size);
  } else {
    fft_multiply(a, a_size, b, b_size, result, result_size);
  }
}

//-------------------- DIVISION -----------------------------------

int basecase_divide_buf[MAXN];

// a >= b, a contains the ans, q & r should have size of a
void basecase_divide(
  const int *a, int a_size,
  const int *b, int b_size,
  int *q, int *q_size,
  int *r, int *r_size)
{
  int d = b[b_size - 1], curr_q, not_used;
  assert(d >= BASE / 2); // normalized divisor
  memcpy(r, a, a_size * sizeof(int));
  if (compare(a, a_size, b, b_size) < 0) {
    *q_size = 0;
    *r_size = a_size;
    return;
  }

  int m = a_size - b_size;
  if (compare(r + a_size - b_size, b_size, b, b_size) >= 0) {
    *q_size = m + 1;
    q[m] = 1;
    inplace_subtract(r + a_size - b_size, b_size, b, b_size, &not_used);
  } else {
    *q_size = m;
  }

  for (int i = m - 1; i >= 0; --i) {
    curr_q = MIN((r[i + b_size] * BASE + r[i + b_size - 1]) / d, BASE - 1);
    int b_mult_size;
    multiply_by_short(b, b_size, curr_q, basecase_divide_buf, &b_mult_size);
    while (compare(r + i, b_size + 1, basecase_divide_buf, b_mult_size) < 0) {
      inplace_subtract(basecase_divide_buf, b_mult_size, b, b_size, &b_mult_size);
      --curr_q;
    }
    inplace_subtract(r + i, b_size + 1, basecase_divide_buf, b_mult_size, &not_used);
    q[i] = curr_q;
  }
  set_size(r, a_size, r_size);
}

int recursive_divide_mul_buf[2 * MAXN];

void recursive_divide(
  const int *a, int a_size,
  const int *b, int b_size,
  int *q, int *q_size,
  int *r, int *r_size)
{
  assert(b[b_size - 1] >= BASE / 2); // normalized divisor
  int m = a_size - b_size;
  assert(a_size >= m);

  if (m <= BASECASE_DIVIDE_THRESHOLD) {
    basecase_divide(a, a_size, b, b_size, q, q_size, r, r_size);
    return;
  }

  int *a_tick = (int *)calloc(2 * a_size, sizeof(int));
  int *q0 = (int *)calloc(2 * a_size, sizeof(int));

  int a_tick_size, mult_size, q1_size, r1_size, q0_size, r0_size, sub = 0;
  int k = m >> 1;

  recursive_divide(
    a + 2 * k, a_size - 2 * k,
    b + k, b_size - k,
    q + k, &q1_size,
    a_tick + 2 * k, &r1_size
  );

  memcpy(a_tick, a, MIN(a_size, 2 * k) * sizeof(int));
  set_size(a_tick, r1_size + 2 * k, &a_tick_size);
  multiply(q + k, q1_size, b, k, recursive_divide_mul_buf, &mult_size);

  int *a_tick_without_k = a_tick + k;
  int a_tick_without_k_size = MAX(a_tick_size - k, 0);

  while (compare(a_tick_without_k, a_tick_without_k_size, recursive_divide_mul_buf, mult_size) < 0) {
    inplace_add(a_tick_without_k, a_tick_without_k_size, b, b_size, &a_tick_without_k_size);
    ++sub;
  }
  inplace_subtract(a_tick_without_k, a_tick_without_k_size, recursive_divide_mul_buf, mult_size, &a_tick_without_k_size);
  assert(sub <= 4);
  if (sub) {
    inplace_subtract(q + k, q1_size, &sub, 1, &q1_size);
  }

  recursive_divide(
    a_tick_without_k, a_tick_without_k_size,
    b + k, b_size - k,
    q0, &q0_size,
    r + k, &r0_size
  );

  memset(r, 0, k * sizeof(int));
  memcpy(r, a_tick, MIN(k, a_tick_size) * sizeof(int));
  set_size(r, r0_size + k, r_size);
  free(a_tick);

  multiply(q0, q0_size, b, k, recursive_divide_mul_buf, &mult_size);
  sub = 0;
  while (compare(r, *r_size, recursive_divide_mul_buf, mult_size) < 0) {
    inplace_add(r, *r_size, b, b_size, r_size);
    ++sub;
  }
  inplace_subtract(r, *r_size, recursive_divide_mul_buf, mult_size, r_size);
  assert(sub <= 4);
  if (sub) {
    inplace_subtract(q0, q0_size, &sub, 1, &q0_size);
  }

  memset(q, 0, k * sizeof(int));
  set_size(q, k + q1_size, q_size);
  inplace_add(q, k + q1_size, q0, q0_size, q_size);
  free(q0);
}

int divide_new_a[MAXN], divide_new_b[MAXN];
int new_a_size, new_b_size;

void divide(
  const int *a, int a_size,
  const int *b, int b_size,
  int *q, int *q_size,
  int *r, int *r_size)
{
  if (b[b_size - 1] < BASE / 2) {
    int mul = 1;
    do {
      mul *= 2;
      multiply_by_short(b, b_size, mul, divide_new_b, &new_b_size);
    } while (divide_new_b[new_b_size - 1] < BASE / 2);
    multiply_by_short(a, a_size, mul, divide_new_a, &new_a_size);
    recursive_divide(divide_new_a, new_a_size, divide_new_b, new_b_size, q, q_size, r, r_size);
    assert(inplace_divide_by_short(r, *r_size, mul, r_size) == 0);
  } else {
    recursive_divide(a, a_size, b, b_size, q, q_size, r, r_size);
  }
}

//--------------------- SQUARE ROOT -------------------------------

int newton_next[2 * MAXN], division_res[2 * MAXN];

// result should have size not less than a_size
void newton_square_root(int *a, int a_size, int *result, int *result_size, int *residue, int *residue_size) {
  if (a_size == 0) {
    *result_size = 0;
    return;
  }

  int base_pow = (a_size + 1) >> 1;
  memset(result, 0, base_pow * sizeof(int));
  result[base_pow] = 1;
  *result_size = base_pow + 1;

  int next_size, division_res_size;
  while (true) {
    divide(a, a_size, result, *result_size, newton_next, &next_size, residue, residue_size);
    memcpy(division_res, newton_next, next_size * sizeof(int));
    division_res_size = next_size;
    
    inplace_add(newton_next, next_size, result, *result_size, &next_size);
    inplace_divide_by_short(newton_next, next_size, 2, &next_size);
    if (compare(result, *result_size, newton_next, next_size) <= 0) {
      break;
    }
    *result_size = next_size;
    memcpy(result, newton_next, next_size * sizeof(int));
  }
     
  while (compare(result, *result_size, division_res, division_res_size) < 0) {
    inplace_subtract(division_res, division_res_size, &ONE, 1, &division_res_size);
    inplace_add(residue, *residue_size, result, *result_size, residue_size);
  }
}

int n[MAXN], sqrt_s[2 * MAXN], sqrt_r[2 * MAXN], s_plus1_times2[2 * MAXN];
int size, s_size, r_size, s_plus1_times2_size;

int main() {
  prepare_fft();
  read_number(n, &size);
  newton_square_root(n, size, sqrt_s, &s_size, sqrt_r, &r_size);
  if (r_size == 0) {
    printf("1\n");
    return 0;
  }
  inplace_add(sqrt_s, s_size, &ONE, 1, &s_size);
  if (compare(sqrt_r, r_size, sqrt_s, s_size) <= 0) {
    write_number(sqrt_r, r_size);
  } else {
    multiply_by_short(sqrt_s, s_size, 2, s_plus1_times2, &s_plus1_times2_size);
    inplace_subtract(s_plus1_times2, s_plus1_times2_size, sqrt_r, r_size, &s_plus1_times2_size);
    write_number(s_plus1_times2, s_plus1_times2_size);
  }
  free_fft();
  return 0;
}